
============
Contributing
============

Contributions are welcome. You can contribute in many ways:

Reporting an issue
~~~~~~~~~~~~~~~~~~

Report an issue on `GitHub <https://github.com/lsst-sqre/kafka-connect-manager/issues>`_.

If you are reporting an issue, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the issue.

Fix bugs or implement features
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Look through the GitHub issues. Anything tagged with "help
wanted" is open to whoever wants to implement it.


Write Documentation
~~~~~~~~~~~~~~~~~~~

Whether as part of  `docs <https://kafka-connect-manager.lsst.io>`_ or docstrings.

Send Feedback
~~~~~~~~~~~~~

The best way to send feedback is to file an `issue <https://github.com/lsst-sqre/kafka-connect-manager/issues>`_.

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.
* Remember that this is an open-source project, and that contributions
  are welcome :)
